==> owncloud-app-contacts-2%3A1.2.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/de.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakte",
    "Address book name" : "Adressbuch Name",
    "No contacts in here" : "Keine Kontakte gefunden",
    "Name" : "Name",
    "Organization" : "Organisation",
    "Title" : "Titel",
    "Add field ..." : "Feld hinzufügen ...",
    "Import" : "Importieren",
    "Add contact" : "Kontakt hinzufügen",
    "No search result for {query}" : "Kein Ergebnis für {query}",
    "All contacts" : "Alle Kontakte",
    "Not grouped" : "Nicht gruppiert",
    "Post Office Box" : "Postfach",
    "Postal Code" : "Postleitzahl",
    "City" : "Stadt",
    "State or province" : "Staat oder Provinz",
    "Country" : "Land",
    "Address" : "Adresse",
    "(new group)" : "(neue Gruppe)",
    "New contact" : "Neuer Kontakt",
    "{addressbook} shared by {owner}" : "{addressbook} geteilt von {owner}",
    "Invalid file type." : "Ungültiger Dateityp.",
    "Nickname" : "Spitzname",
    "Notes" : "Notizen",
    "Website" : "Website",
    "Federated Cloud ID" : "Federated-Cloud-ID",
    "Home" : "Home",
    "Work" : "Arbeit",
    "Other" : "Andere",
    "Groups" : "Gruppen",
    "Birthday" : "Geburtstag",
    "Email" : "E-Mail",
    "Instant messaging" : "Instant Messaging",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Fax" : "Fax",
    "Fax home" : "Fax persönlich",
    "Fax work" : "Fax geschäftlich",
    "Pager" : "Pager",
    "Voice" : "Anruf",
    "Social Network" : "Soziales Netzwerk",
    "Settings" : "Einstellungen"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-contacts-2%3A1.3.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/de.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakte",
    "Address book name" : "Adressbuch Name",
    "No contacts in here" : "Keine Kontakte gefunden",
    "Name" : "Name",
    "Organization" : "Organisation",
    "Title" : "Titel",
    "Add field ..." : "Feld hinzufügen ...",
    "Import" : "Importieren",
    "Add contact" : "Kontakt hinzufügen",
    "No search result for {query}" : "Kein Ergebnis für {query}",
    "All contacts" : "Alle Kontakte",
    "Not grouped" : "Nicht gruppiert",
    "Post Office Box" : "Postfach",
    "Postal Code" : "Postleitzahl",
    "City" : "Stadt",
    "State or province" : "Staat oder Provinz",
    "Country" : "Land",
    "Address" : "Adresse",
    "(new group)" : "(neue Gruppe)",
    "New contact" : "Neuer Kontakt",
    "{addressbook} shared by {owner}" : "{addressbook} geteilt von {owner}",
    "No contacts in file. Only VCard files are allowed." : "Keine Kontakte in der Datei. Nur VCard-Dateien sind erlaubt.",
    "Nickname" : "Spitzname",
    "Notes" : "Notizen",
    "Website" : "Website",
    "Federated Cloud ID" : "Federated-Cloud-ID",
    "Home" : "Home",
    "Work" : "Arbeit",
    "Other" : "Andere",
    "Groups" : "Gruppen",
    "Birthday" : "Geburtstag",
    "Email" : "E-Mail",
    "Instant messaging" : "Instant Messaging",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Fax" : "Fax",
    "Fax home" : "Fax persönlich",
    "Fax work" : "Fax geschäftlich",
    "Pager" : "Pager",
    "Voice" : "Anruf",
    "Social Network" : "Soziales Netzwerk",
    "Settings" : "Einstellungen"
},
"nplurals=2; plural=(n != 1);");
